@@ -35,6 +35,14 @@ KiokuDB::Backend::Role::Query - Backend specific query API
 
 =head1 DESCRIPTION
 
+This role is for backend specific searching. Anything that is not
+L<KiokuDB::Backend::Role::Query::Simple> is a backend specific search, be it a
+L<Search::GIN::Query>, or something else.
+
+The backend is expected to interpret the search arguments which are passed
+through from L<KiokuDB/search> as is, and return a L<Data::Stream::Bulk> of
+matching entries.
+
 =cut
 
 
